@@ -85,6 +85,18 @@ def decode_outputs(regression, classification, confidence_threshold=0.01,
 
 def filter(regression_, classification_, confidence_threshold, nms_threshold,
            max_detections):
+    """ Filter network outputs by their score and nms_threshold.
+
+    Args:
+        regression_: Regression network outputs.
+        classification_: Classification network outputs.
+        confidence_threshold: Score threshold.
+        nms_threshold: NMS threshold.
+        max_detections: Number of max detections to keep.
+
+    Returns: Filtered scores and boxes.
+
+    """
     boxes, scores, confidence_indexes = filter_by_scores(regression_,
                                                          classification_,
                                                          confidence_threshold)
@@ -101,20 +113,22 @@ def filter(regression_, classification_, confidence_threshold, nms_threshold,
 
 
 def filter_by_nms_threshold(boxes, scores, max_detections, nms):
+    """ Filter by nms threshold.
+    """
     nms = tf.image.non_max_suppression(boxes, scores, max_detections, nms)
 
     return tf.expand_dims(nms, axis=1)
 
 
 def filter_by_scores(regression, classification, confidence_threshold):
-    """
+    """ Filter network outputs by their scores.
 
     Args:
         regression: Network offset values.
         classification: Network scores.
         confidence_threshold: Score threshold.
 
-    Returns:
+    Returns: Filtered boxes, scores, filter_indexes.
 
     """
     scores = tf.math.reduce_max(classification, axis=1)
@@ -152,14 +166,14 @@ def get_highest_scores(scores):
 
 
 def concatenate_predictions(boxes, scores, labels):
-    """
+    """ Change way of storing predictions from list elements into tensor.
 
     Args:
         boxes: Bounding box detections.
         scores: Highest score for each detection.
         labels: Label for each detection.
 
-    Returns:
+    Returns: Tensor objects.
 
     """
     boxes = tf.stack(boxes, axis=0)
@@ -170,6 +184,8 @@ def concatenate_predictions(boxes, scores, labels):
 
 
 def fill_array(boxes, scores, labels, fill):
+    """ Make tensors to same size to avoid ragged tensors..
+    """
     fill_boxes = tf.cast(tf.fill((fill, 4), 0), dtype=tf.float32)
     fill_scores = tf.cast(tf.fill((fill, 1), 0), dtype=tf.float32)
     fill_labels = tf.cast(tf.fill((fill, 1), 0), dtype=tf.int64)
@@ -181,16 +197,7 @@ def fill_array(boxes, scores, labels, fill):
 
 
 def get_top_k(scores, boxes, labels, max_detections):
-    """
-
-    Args:
-        scores:
-        boxes:
-        labels:
-        max_detections:
-
-    Returns:
-
+    """ Get top-k predictions w.r.t. number max_detections.
     """
     k = tf.math.minimum(max_detections, tf.keras.backend.shape(scores)[0])
     scores, top_indexes = tf.nn.top_k(scores, k=k)
